@@ -1,7 +1,7 @@
+# this function from usthis:::view_url
 #' @importFrom utils browseURL
 #' @importFrom usethis ui_todo ui_done
-view_url <- function(..., open = interactive()) {
-  url <- paste(..., sep = "/")
+view_url <- function(url, open = interactive()) {
   if (open) {
     ui_done("Opening URL {url}")
     utils::browseURL(url)
